//
// CYBERSOURCE CORPORATION ("COMPANY") CONFIDENTIAL
// Copyright (c) 2021 CyberSource Corporation. All Rights Reserved.
//
// NOTICE:  All information contained herein is, and remains the property of COMPANY. The intellectual and technical concepts contained
// herein are proprietary to COMPANY and may be covered by European or foreign Patents, patents in process, and are protected by trade secret or copyright law.
// Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
// from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed
// Confidentiality and Non-disclosure agreements explicitly covering such access.
//
// The copyright notice above does not evidence any actual or intended publication or disclosure of this source code, which includes
// information that is confidential and/or proprietary, and is a trade secret, of COMPANY.
// ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE,
// OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE
// LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS
// TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.


/**
 * Describes the status of the tip adjustment for a transaction.
 * @since 2.22.0
 */
typedef NS_ENUM(NSUInteger, MPTransactionTipAdjustStatus) {
    MPTransactionTipAdjustStatusUnknown,
    MPTransactionTipAdjustStatusAdjustable,
    MPTransactionTipAdjustStatusNotAdjustable,
    MPTransactionTipAdjustStatusAdjusted
};


@import Foundation;


/**
 * Extra details of a transaction, e.g. fees or tips.
 * @since 2.7.0
 */
@interface MPTransactionDetails : NSObject


/**
 * Application fee of the transaction.
 * @since 2.7.0
 */
@property (nonatomic, strong, readonly, nullable) NSDecimalNumber *applicationFee;


/**
 * Tip amount included in the transaction.
 * @since 2.7.0
 */
@property (nonatomic, strong, readonly, nullable) NSDecimalNumber *includedTipAmount;

/**
 * Metadata of the transaction.
 * @since 2.7.0
 */
@property (nonatomic, strong, readonly, nullable) NSDictionary<NSString *, NSString *> *metadata;

/**
 * Status of tip adjustment for the transaction.
 * @since 2.22.0
 */
@property (nonatomic, assign, readonly) MPTransactionTipAdjustStatus tipAdjustStatus;


@end
